@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0203';
+our $VERSION = '0.0204';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
@@ -237,12 +237,11 @@ sub substitution {
 
     my $substitute = $chord;
 
-    if (
-        $chord eq ''
-        || $chord eq 'm'
-        || $chord eq 'dim'
-        || $chord eq 'aug'
-    ) {
+    if ($chord eq '' || $chord eq 'm') {
+        my $roll = int rand 2;
+        $substitute = $roll == 0 ? $chord . 'M7' : $chord . 7;
+    }
+    elsif ($chord eq 'dim' || $chord eq 'aug') {
         $substitute = $chord . 7;
     }
     elsif ($chord eq '-5' || $chord eq '-9') {
@@ -261,7 +260,7 @@ sub substitution {
         $substitute = $roll == 0 ? 'm9' : $roll == 1 ? 'm11' : 'm13';
     }
 
-    print "Substitute: $chord => $substitute\n" if $self->verbose && $substitute ne $chord;
+    print qq|Substitute: "$chord" => "$substitute"\n| if $self->verbose && $substitute ne $chord;
 
     return $substitute;
 }
@@ -280,7 +279,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0203
+version 0.0204
 
 =head1 SYNOPSIS
 
